<?php
if ( !class_exists( 'ReduxFramework' ) && file_exists( dirname( __FILE__ ) . '/ReduxFramework/ReduxCore/framework.php' ) ) {
    require_once( dirname( __FILE__ ) . '/ReduxFramework/ReduxCore/framework.php' );
}
if ( !isset( $redux_demo ) && file_exists( dirname( __FILE__ ) . '/lib/theme-options.php' ) ) {
    require_once( dirname( __FILE__ ) . '/lib/theme-options.php' );
}

function justice_setup() {
	register_nav_menu( 'primary', __( 'Primary Menu', 'justice' ) );
	add_theme_support( 'post-thumbnails' );
}
add_action( 'after_setup_theme', 'justice_setup' );


function justice_scripts_styles() {
	wp_enqueue_style( 'justice-style', get_stylesheet_uri() );
}
add_action( 'wp_enqueue_scripts', 'justice_scripts_styles' );


function justice_wp_title( $title, $sep ) {
	global $paged, $page;
	if ( is_feed() )
		return $title;

	$title .= get_bloginfo( 'name' );

	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'justice' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'justice_wp_title', 10, 2 );


function justice_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'justice' ),
		'id' => 'sidebar-1',
		'description' => __( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'justice' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Home Middle Widget Area', 'justice' ),
		'id' => 'sidebar-home',
		'description' => __( 'Widgets in this area will be shown on Home Middle.', 'justice' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'justice_widgets_init' );



if ( ! function_exists( 'justice_content_nav' ) ) :
function justice_content_nav( $html_id ) {
	global $wp_query;

	$html_id = esc_attr( $html_id );

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">
			<h3 class="assistive-text"><?php _e( 'Post navigation', 'justice' ); ?></h3>
			<div class="nav-previous alignleft"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'justice' ) ); ?></div>
			<div class="nav-next alignright"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'justice' ) ); ?></div>
		</nav><!-- #<?php echo $html_id; ?> .navigation -->
	<?php endif;
}
endif;


function nav_class_filter( $var ) {
	return is_array($var) ? array_intersect($var, array('current-menu-item')) : '';
}
add_filter('nav_menu_css_class', 'nav_class_filter', 100, 1);


require_once dirname( __FILE__ ) . '/class-tgm-plugin-activation.php';
 
add_action( 'tgmpa_register', 'my_theme_register_required_plugins' );

function my_theme_register_required_plugins() {
	$plugins = array(
		array(
			'name'     				=> 'Formidable', // The plugin name
			'slug'     				=> 'formidable',
		),	
		array(
			'name'     				=> 'Custom Sidebars', // The plugin name
			'slug'     				=> 'custom-sidebars',
		),
		array(
			'name'     				=> 'Meta Box', // The plugin name
			'slug'     				=> 'meta-box',
			'required'				=> true
		),
		array(
			'name'     				=> 'WP Bannerize', // The plugin name
			'slug'     				=> 'wp-bannerize',
		),
	);

	$theme_text_domain = 'justice';

	$config = array(
		'domain'       		=> $theme_text_domain, // Text domain - likely want to be the same as your theme.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
		'strings'      		=> array(
			'page_title'                       			=> __( 'Install Required Plugins', $theme_text_domain ),
			'menu_title'                       			=> __( 'Install Plugins', $theme_text_domain ),
			'installing'                       			=> __( 'Installing Plugin: %s', $theme_text_domain ), // %1$s = plugin name
			'oops'                             			=> __( 'Something went wrong with the plugin API.', $theme_text_domain ),
			'notice_can_install_required'     			=> _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_install_recommended'			=> _n_noop( '', '' ), // %1$s = plugin name(s)
			'notice_cannot_install'  					=> _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s)
			'notice_can_activate_required'    			=> _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_activate_recommended'			=> _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_activate' 					=> _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s)
			'notice_ask_to_update' 						=> _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_update' 						=> _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s)
			'install_link' 					  			=> _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
			'activate_link' 				  			=> _n_noop( 'Activate installed plugin', 'Activate installed plugins' ),
			'return'                           			=> __( 'Return to Required Plugins Installer', $theme_text_domain ),
			'plugin_activated'                 			=> __( 'Plugin activated successfully.', $theme_text_domain ),
			'complete' 									=> __( 'All plugins installed and activated successfully. %s', $theme_text_domain ), // %1$s = dashboard link
			'nag_type'									=> 'updated' // Determines admin notice type - can only be 'updated' or 'error'
		)
	);

	tgmpa( $plugins, $config );
}

function the_breadcrumb() {
    $sep = '<span>/</span>';
    if (!is_front_page()) {
        echo '<div class="breadcrumbs">';
        echo '<a href="';
        echo get_option('home');
        echo '">Home</a>' . $sep;
        if (is_category() || is_single() ){
        	the_category('title_li=');
        } elseif (is_archive() || is_single()){
            if ( is_day() ) {
            	printf( __( '%s', 'text_domain' ), get_the_date() );
            } elseif ( is_month() ) {
                printf( __( '%s', 'text_domain' ), get_the_date( _x( 'F Y', 'monthly archives date format', 'text_domain' ) ) );
            } elseif ( is_year() ) {
                printf( __( '%s', 'text_domain' ), get_the_date( _x( 'Y', 'yearly archives date format', 'text_domain' ) ) );
            } else {
                _e( 'Blog Archives', 'text_domain' );
            }
        }
        if (is_single()) {
            echo $sep;
            the_title();
        }
        if (is_page()) {
            echo the_title();
        }
        if (is_home()){
            global $post;
            $page_for_posts_id = get_option('page_for_posts');
            if ( $page_for_posts_id ) { 
                $post = get_page($page_for_posts_id);
                setup_postdata($post);
                the_title();
                rewind_posts();
            }
        }
        echo '</div>';
    }
}

add_action( 'admin_init', 'rw_register_meta' );
function rw_register_meta()
{
    if ( !class_exists( 'RW_Meta_Box' ) )
        return;
    $prefix = 'rw_';
    $meta_boxes = array();
    // 1st meta box
    $meta_boxes[] = array(
        'title'    => 'Top Header Image',
        'pages'    => array( 'page', 'attorney' ),
        'context'  => 'side',
        'priority' => 'low',
        'fields' => array(
            array(
	            'name' => 'Main Banner in Page (1024 x 185px)',
	            'desc'  => 'Use this space to set the main image in the top part of every page. If you leave blank, a image by default will be used for filling up this position.',
	            'id'   => $prefix . 'banner',
	            'type' => 'image_advanced',
	            'max_file_uploads' => 1,
            )
        )
    );
    foreach ( $meta_boxes as $meta_box )
    {
    	new RW_Meta_Box( $meta_box );
    }
}

function n2wp_latest_cpt($args) {
	global $post;
	extract($args);
	$options 		= get_option( 'n2wp_latest_cpt' );
	$title 			= $options['title']; // Widget title
	$phead 			= $options['phead']; // Heading format
	$pshow 			= $options['pshow']; // Number of Tweets
	$ppostdate 		= $options['postdate']; // Number of Tweets
	$beforetitle 	= '<h3 class="widget-title">';
	$aftertitle 	= '</h3>';

	echo $before_widget;
	if ($title) echo $beforetitle . $title . $aftertitle;

	$pq = new WP_Query(array( 'post_type' => 'post', 'showposts' => $pshow ));

	if( $pq->have_posts() ) :
		if( !$ppostdate ){
			echo '<ul>';
			while($pq->have_posts()) : $pq->the_post(); ?>
				<li><a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a></li>
				<?php wp_reset_query();
			endwhile;
			echo '</ul>';
		}else{
			echo '<section>';
			while($pq->have_posts()) : $pq->the_post(); ?>
				<article>
					<div class="date">
                    	<div class="content-date">
                    		<span class="day"><?php the_time('d'); ?></span><br>
                    		<span class="month"><?php the_time('M'); ?></span><br>
                        	<span class="year"><?php the_time('Y'); ?></span>
                    	</div>
                    </div>
                    <p><?php the_title(); ?></p>
                    <a href="<?php echo get_permalink(); ?>" class="read-more">Read More</a>
				</article>
			<?php wp_reset_query();
			endwhile;
			echo '</section>';
		}
	endif; ?>
	<?php
	echo $after_widget;
}

function n2wp_latest_cpt_control() {
	$options = get_option( 'n2wp_latest_cpt' );
	if ( !is_array( $options ))
		$options = array(
			'title' 	=> 'News & Articles',
			'phead' 	=> 'h3',
			'pshow' 	=> '3',
			'postdate' 	=> '1'
		);
	if ( $_POST['latest-cpt-submit'] ) {
		$options['title'] = strip_tags( $_POST['latest-cpt-title'] );
		$options['phead'] = $_POST['latest-cpt-phead'];
		$options['pshow'] = $_POST['latest-cpt-pshow'];
		$options['postdate'] = $_POST['latest-cpt-postdate'];
		update_option( 'n2wp_latest_cpt', $options );
	}
	$title 		= $options['title'];
	$phead 		= $options['phead'];
	$pshow 		= $options['pshow'];
	$ppostdate 	= $options['postdate'];
	?>
	<p><label for="latest-cpt-title"><?php echo __( 'Title' ); ?><br />
		<input id="latest-cpt-title" type="text" name="latest-cpt-title" value="<?php echo $title; ?>" size="30" />
	</label></p>
	<p><label for="latest-cpt-pshow"><?php echo __( 'Number of posts to show' ); ?><br />
		<input id="latest-cpt-pshow" type="text" name="latest-cpt-pshow" value="<?php echo $pshow; ?>" size="2" />
	</label></p>
	<p><label for="latest-cpt-postdate"><?php echo __( 'Display post date?' ); ?>&nbsp;
		<input id="latest-cpt-postdate" class="checkbox" type="checkbox" name="latest-cpt-postdate" <?php checked($ppostdate, 'on'); ?> />
	</label></p>
	<input id="latest-cpt-submit" type="hidden" name="latest-cpt-submit" value="1" />
<?php
}
wp_register_sidebar_widget( 'widget_latest_cpt', __('News & Articles'), 'n2wp_latest_cpt' );
wp_register_widget_control( 'widget_latest_cpt', __('News & Articles'), 'n2wp_latest_cpt_control', 300, 200 );


add_action( 'init', 'create_post_type_attorney' );
function create_post_type_attorney() {
  register_post_type( 'attorney',
      array(
        'labels' => array(
          'name' => __( 'Attorney' ),
          'singular_name' => __( 'Attorney' ),
          'add_new' => __( 'Add New' ),  
          'add_new_item' => __( 'Add New' ),  
          'edit_item' => __( 'Edit' ),  
          'new_item' => __( 'New' ),  
          'view_item' => __( 'View' ),  
        ),
       'query_var' => true,
       'has_archive' => true,
       'rewrite' => array('slug' => 'attorney'),
       'capability_type' => 'post',
       'public' => true,
       'has_archive' => true,
       'menu_position' => 5,
       'hierarchical' => true,
       'supports' => array('title','editor','thumbnail','page-attributes')
      )
  );
}

add_action( 'admin_init', 'rw_register_meta_attorney' );
function rw_register_meta_attorney()
{
    if ( !class_exists( 'RW_Meta_Box' ) )
        return;
    $prefix = 'rw_';
    $meta_boxes = array();
    // 1st meta box
    $meta_boxes[] = array(
        'title'    => 'vCard',
        'pages'    => array( 'attorney' ),
        'context'  => 'side',
        'priority' => 'low',
        'fields' => array(
            array(
                'name' => 'First Name',
                'id'   => $prefix . 'first_name',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Last Name',
                'id'   => $prefix . 'last_name',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Organization',
                'id'   => $prefix . 'organization',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Title',
                'id'   => $prefix . 'title',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Telephone Office',
                'id'   => $prefix . 'telephone_office',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Telephone Direct',
                'id'   => $prefix . 'telephone_direct',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Address Street',
                'id'   => $prefix . 'address_street',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Address City',
                'id'   => $prefix . 'address_city',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Address State',
                'id'   => $prefix . 'address_state',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Address ZIP Code',
                'id'   => $prefix . 'address_zip',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Address Country',
                'id'   => $prefix . 'address_country',
                'type' => 'text',
                'desc' => ''
            ),
            array(
                'name' => 'Email',
                'id'   => $prefix . 'email',
                'type' => 'text',
                'desc' => ''
            ),
        )
    );
    foreach ( $meta_boxes as $meta_box )
    {
        new RW_Meta_Box( $meta_box );
    }
}


add_action( 'init', 'create_post_type_testimonials' );
function create_post_type_testimonials() {
	register_post_type( 'testimonials',
		array(
      		'labels' => array(
		        'name' => __( 'Testimonials' ),
		        'singular_name' => __( 'Testimonials' ),
		        'add_new' => __( 'Add New' ),  
		        'add_new_item' => __( 'Add New' ),  
		        'edit_item' => __( 'Edit' ),  
		        'new_item' => __( 'New' ),  
		        'view_item' => __( 'View' ),  
      		),
			'query_var' => true,
			'has_archive' => true,
			'rewrite' => array('slug' => 'testimonials'),
			'capability_type' => 'post',
			'public' => true,
			'has_archive' => true,
			'menu_position' => 5,
			'hierarchical' => true,
			'supports' => array('title','editor','page-attributes')
		)
	);
}

function n2wp_testimonials_cpt($args) {
	global $post;
	extract($args);
	$options 		= get_option( 'n2wp_testimonials_cpt' );
	$title 			= $options['title']; // Widget title
	$phead 			= $options['phead']; // Heading format
	$beforetitle 	= '<h3 class="widget-title">';
	$aftertitle 	= '</h3>';

	echo $before_widget;
	if ($title) echo $beforetitle . $title . $aftertitle;
	$pq = new WP_Query(array( 'post_type' => 'testimonials', 'showposts' => -1 ));

	if( $pq->have_posts() ) :
		echo '<div id="quotearea" style="font-size:12px;" class="bxslider">';
		while($pq->have_posts()) : $pq->the_post(); ?>
			<div class="quoterotator" style="display: block; opacity: 0.8774692710207257;">
				<span id="quote">
                	<?php the_excerpt(); ?>
                </span> 
                <span id="quoteauthor"><?php the_title(); ?></span>
			</div>
		<?php wp_reset_query();
		endwhile;
		echo '</div>';
	endif; ?>
	<?php
	echo $after_widget;
}

function n2wp_testimonials_cpt_control() {
	$options = get_option( 'n2wp_testimonials_cpt' );
	if ( !is_array( $options ))
		$options = array(
			'title' 	=> 'Testimonials',
			'phead' 	=> 'h3'
		);
	if ( $_POST['testimonials-cpt-submit'] ) {
		$options['title'] = strip_tags( $_POST['testimonials-cpt-title'] );
		$options['phead'] = $_POST['testimonials-cpt-phead'];
		update_option( 'n2wp_testimonials_cpt', $options );
	}
	$title 		= $options['title'];
	$phead 		= $options['phead'];
	?>
	<p><label for="testimonials-cpt-title"><?php echo __( 'Title' ); ?><br />
		<input id="testimonials-cpt-title" type="text" name="testimonials-cpt-title" value="<?php echo $title; ?>" size="30" />
	</label></p>
	<input id="testimonials-cpt-submit" type="hidden" name="testimonials-cpt-submit" value="1" />
<?php
}
wp_register_sidebar_widget( 'widget_testimonials_cpt', __('Testimonials'), 'n2wp_testimonials_cpt' );
wp_register_widget_control( 'widget_testimonials_cpt', __('Testimonials'), 'n2wp_testimonials_cpt_control', 300, 200 );


add_action( 'widgets_init', 'my_widget_buttonlink' );
function my_widget_buttonlink() {
	register_widget( 'MY_Widget_ButtonLink' );
}

class MY_Widget_ButtonLink extends WP_Widget {
	function MY_Widget_ButtonLink() {
		$widget_ops = array( 'classname' => 'buttonlink-page', 'description' => __('This widget will display Button Link Page.', 'justice') );
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'widget-buttonlink' );
		$this->WP_Widget( 'widget-buttonlink', __('Button Link Page', 'buttonlink-page'), $widget_ops, $control_ops );
	}
	
	function widget( $args, $instance ) {
		extract( $args );
		//Our variables from the widget settings.
		$title 	= apply_filters('widget_title', $instance['title'] );
       	$idpage = apply_filters('widget_idpage', $instance['idpage'] );

		echo $before_widget;
		echo '<a href="'.get_permalink( $idpage ).'" class="btn-siderbar">'.$title.'</a>';
        echo $after_widget; // end widget display code
	}

	//Update the widget 
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		//Strip tags from title and name to remove HTML 
		$instance['title'] = strip_tags( $new_instance['title'] );
        $instance['idpage'] = strip_tags( $new_instance['idpage'] );
		return $instance;
	}

	function form( $instance ) {
		//Set up some default widget settings.
		$defaults = array( 'title' => __('', 'justice'), 'idpage' => __('','justice'));
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'justice'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>
        <p>
			<label for="<?php echo $this->get_field_id( 'idpage' ); ?>"><?php _e('Page:', 'justice'); ?></label>
            <select id="<?php echo $this->get_field_id( 'idpage' ); ?>" name="<?php echo $this->get_field_name( 'idpage' ); ?>" style="width:100%;">
	            <?php
	            query_posts( 'post_type=page&orderby=post_date&order=DESC&posts_per_page=-1');
				while (have_posts()) : the_post();
					$do_not_duplicate = $post->ID;
	            ?>
	            <option value="<?php echo get_the_ID(); ?>" <?php if($instance['idpage'] == get_the_ID()){ ?> selected="selected"<?php } ?>><?php the_title(); ?></option>
	            <?php
	            endwhile;
	            wp_reset_query(); 
	            ?>
    		</select>
		</p> 
	<?php
	}
}


add_action( 'widgets_init', 'my_widget_buttonblog' );
function my_widget_buttonblog() {
	register_widget( 'MY_Widget_ButtonBlog' );
}

class MY_Widget_ButtonBlog extends WP_Widget {
	function MY_Widget_ButtonBlog() {
		$widget_ops = array( 'classname' => 'buttonblog-page', 'description' => __('This widget will display Button Link Blog.', 'justice') );
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'widget-buttonblog' );
		$this->WP_Widget( 'widget-buttonblog', __('Button Link Blog', 'buttonblog-page'), $widget_ops, $control_ops );
	}
	
	function widget( $args, $instance ) {
		extract( $args );
		//Our variables from the widget settings.
		$title 	= apply_filters('widget_title', $instance['title'] );
       	$urlblog = get_bloginfo('wpurl');

		echo $before_widget;
		if( get_option( 'show_on_front' ) == 'page' ) $urlblog = get_permalink( get_option('page_for_posts' ) );
		echo '<a href="'.$urlblog.'" id="btn-articles">READ OUR<span>'.$title.'</span></a>';
        echo $after_widget; // end widget display code
	}

	//Update the widget 
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		//Strip tags from title and name to remove HTML 
		$instance['title'] = strip_tags( $new_instance['title'] );
		return $instance;
	}

	function form( $instance ) {
		//Set up some default widget settings.
		$defaults = array( 'title' => __('', 'justice') );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'justice'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>
	<?php
	}
}

function my_custom_login_logo() {
	echo '<style  type="text/css"> .login h1 a { background-image:url(' . get_template_directory_uri() . '/images/login.svg)  !important; width:300px!important; height:82px!important; margin:0 auto; background-size:300px!important;} </style>';
}
add_action('login_head',  'my_custom_login_logo');

function remove_footer_admin ()  {  
	echo '<span id="footer-thankyou">Developed by <a href="http://www.culturainteractive.com" target="_blank">Cultura Interactive</a>. Powered by <a href="http://www.wordpress.org">WordPress</a></span>';  
}  
add_filter('admin_footer_text', 'remove_footer_admin');
?>