<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * For example, it puts together the home page when no home.php file exists.
 *
 * Learn more: http://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Justice
 */

get_header(); ?>
<?php 
	$page_for_posts = get_option( 'page_for_posts' );

    $src = get_template_directory_uri().'/images/banner-interno.jpg';

    $files = get_post_meta( $page_for_posts, 'rw_banner', false );
    if($files){
        foreach ( $files as $att ){
            $src = wp_get_attachment_image_src( $att, 'full' );
            $src = $src[0];
        }
    }else{
        $parents = get_post_ancestors( $page_for_posts );
        if( is_array( $parents ) && count( $parents ) > 0 ){
            $files = get_post_meta( $parents[0], 'rw_banner', false );
            if($files){
                foreach ( $files as $att ){
                    $src = wp_get_attachment_image_src( $att, 'full' );
                    $src = $src[0];
                }
            }
        }
    }
?>
	<div id="slider-content">
        <div class="slider-page">
            <h2><?php echo get_the_title( $page_for_posts ); ?></h2>
            <img src="<?php echo $src; ?>" border="0">
    	</div>
    </div>
</header>
<div id="container" class="template-blog">
    <div id="breadcrumbs">
        <?php the_breadcrumb() ?>
    </div>
    <?php get_sidebar(); ?>
    <div class="content-left">
    	<h1 class="entry-title"><?php echo get_the_title( $page_for_posts ); ?></h1>
    	<?php 
        if ( have_posts() ) :
	        while ( have_posts() ) : the_post(); ?>
	    		<article class="post">
	    			<h3><a href="<?php echo get_permalink(); ?>"><?php the_title(); ?></a></h3>
		    		<span class="date"><?php the_date(); ?></span>
		            <?php the_excerpt(); ?>
		            <a class="read-more" href="<?php echo get_permalink(); ?>">Read More</a>
	    		</article>
	        <?php 
	        endwhile; wp_reset_query(); // end of the loop. ?>

        	<?php justice_content_nav( 'nav-below' ); ?>
    	<?php 
    	else : ?>
        	<article id="post-0" class="post no-results not-found">

			<?php if ( current_user_can( 'edit_posts' ) ) :
				// Show a different message to a logged-in user who can add posts.
			?>
				<header class="entry-header">
					<h1 class="entry-title"><?php _e( 'No posts to display', 'fabulous' ); ?></h1>
				</header>

				<div class="entry-content">
					<p><?php printf( __( 'Ready to publish your first post? <a href="%s">Get started here</a>.', 'fabulous' ), admin_url( 'post-new.php' ) ); ?></p>
				</div><!-- .entry-content -->

			<?php else :
				// Show the default message to everyone else.
			?>
				<header class="entry-header">
					<h1 class="entry-title"><?php _e( 'Nothing Found', 'fabulous' ); ?></h1>
				</header>

				<div class="entry-content">
					<p><?php _e( 'Apologies, but no results were found. Perhaps searching will help find a related post.', 'fabulous' ); ?></p>
					<?php get_search_form(); ?>
				</div><!-- .entry-content -->
			<?php endif; // end current_user_can() check ?>

			</article><!-- #post-0 -->
    	<?php 
    	endif; // end have_posts() check ?>
	</div>
</div>

<?php get_footer(); ?>